import QtQuick 2.0
import Ubuntu.Components 1.1

Item{
    id: dateRootItem

    property int date;
    property bool isCurrentMonth;
    property bool isToday

    property alias fontSize: dateLabel.font.pixelSize

    Loader {
        sourceComponent: isToday && isCurrentMonth ? highLightComp : undefined
        onSourceComponentChanged: {
            width =  Qt.binding( function() { return parent.width < parent.height ? parent.width : parent.height } );
            height = Qt.binding ( function() { return width} );
            anchors.centerIn = Qt.binding( function() { return parent});
        }
    }

    Label {
        id: dateLabel
        anchors.centerIn: parent
        width: parent.width
        text: date
        horizontalAlignment: Text.AlignHCenter
        color: {
            if( isCurrentMonth ) {
                if(isToday) {
                    "white"
                } else {
                    "#5D5D5D"
                }
            } else {
                "#AEA79F"
            }
        }
    }

    Loader{
        property bool shouldLoad: showEvents
                                  && intern.eventStatus !== undefined
                                  && intern.eventStatus[index] !== undefined
                                  &&intern.eventStatus[index]
        sourceComponent: shouldLoad ? eventIndicatorComp : undefined
        onSourceComponentChanged: {
            anchors.top = Qt.binding( function() { return dateLabel.bottom } );
            anchors.horizontalCenter =  Qt.binding( function () { return dateLabel.horizontalCenter } );
        }
    }

    MouseArea {
        anchors.fill: parent
        onPressAndHold: {
            var selectedDate = new Date();
            selectedDate.setFullYear(intern.monthStartYear)
            selectedDate.setMonth(intern.monthStartMonth + 1)
            selectedDate.setDate(date)
            selectedDate.setMinutes(60, 0, 0)
            pageStack.push(Qt.resolvedUrl("NewEvent.qml"), {"date":selectedDate, "model":eventModel});
        }
        onClicked: {
            var selectedDate = new Date(intern.monthStartYear,
                                        intern.monthStartMonth,
                                        intern.monthStartDate + index, 0, 0, 0, 0)
            //If monthView is clicked then open selected DayView
            if ( isYearView === false ) {
                root.dateSelected(selectedDate);
            }
            //If yearView is clicked then open selected MonthView
            else {
                root.monthSelected(selectedDate);
            }
        }
    }
}
